.. _changelog:

=========
CHANGELOG
=========


.. _changelog-v0.0.2:

v0.0.2 (2025-02-19)
===================

Unknown
-------

* add notes (`3069337`_)

* Merge branch 'main' of github.com:starccato/starccato_sampler (`6d7dff7`_)

.. _3069337: https://github.com/starccato/starccato_sampler/commit/306933712d30881097cad7c62d6bd975a8281940
.. _6d7dff7: https://github.com/starccato/starccato_sampler/commit/6d7dff774a28b5dc93dfa913b074baa736eb794f


.. _changelog-v0.0.1:

v0.0.1 (2025-02-18)
===================

Bug Fixes
---------

* fix: add analytical evidence (`b43f6f8`_)

* fix: edit description (`9dd8873`_)

Chores
------

* chore(release): 0.0.1 (`98c207f`_)

Unknown
-------

* init project (`89a4278`_)

* Initial commit (`88ede42`_)

.. _b43f6f8: https://github.com/starccato/starccato_sampler/commit/b43f6f8b6358e26884930f280397100e268fe929
.. _9dd8873: https://github.com/starccato/starccato_sampler/commit/9dd88736b267e275cfe9f65d937bc693863eb1b9
.. _98c207f: https://github.com/starccato/starccato_sampler/commit/98c207fbe717b4da1b32d38a516d37db3bc4f47b
.. _89a4278: https://github.com/starccato/starccato_sampler/commit/89a42788db798a39075879c91220dbb653c272cd
.. _88ede42: https://github.com/starccato/starccato_sampler/commit/88ede4295f39fa76d4d8782404cb2855f71bb4de
